@@ -1,6 +1,6 @@
 run_local <- function(responses, nfact, start_item, nitems, thetas.start_in, 
-                      score, design, test, progress, verbose = FALSE, cl = NULL, 
-                      primeCluster = TRUE){
+                      score, design, test, progress, 
+                      verbose = FALSE, cl = NULL, primeCluster = TRUE){
     
     fn <- function(n, responses, nfact, start_item, nitems, thetas.start_in, 
                    score, verbose, design, test){
@@ -26,8 +26,9 @@ run_local <- function(responses, nfact, start_item, nitems, thetas.start_in,
                 person$responses[pick] <- as.integer(ip == test@item_answers[[pick]])
             
             #update Thetas
-            person$Update.thetas(design, test)
-            design <- Update.stop_now(design, person)
+            design@Update.thetas(design=design, person=person, test=test)
+            person$Update.info_mats(design=design, test=test)
+            design <- Update.stop_now(design, person=person)
             if(design@stop_now) break
             
             design <- Next.stage(design, person=person, test=test, item=i)
